==> qtforkawesome-0.2.2-1-x86_64.pkg.tar.zst: usr/share/qtforkawesomeiconengine/cmake/qtforkawesomeiconengineConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(qtforkawesomeiconengine_varname "QT_FORK_AWESOME_ICON_ENGINE")
set(qtforkawesomeiconengine_varname "QT_FORK_AWESOME_ICON_ENGINE")
set(QT_FORK_AWESOME_ICON_ENGINE_DISPLAY_NAME "QIconEngine for ForkAwesome")
set(QT_FORK_AWESOME_ICON_ENGINE_AUTHOR "Martchus")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION "0.2.2")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_MAJOR "0")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_MINOR "2")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_PATCH "2")
set(QT_FORK_AWESOME_ICON_ENGINE_GIT_REV_COUNT "")
set(QT_FORK_AWESOME_ICON_ENGINE_GIT_LAST_COMMIT_ID "")
set(QT_FORK_AWESOME_ICON_ENGINE_URL "https://github.com/Martchus/qtforkawesome")
set(QT_FORK_AWESOME_ICON_ENGINE_DESCRIPTION "QIconEngine for ForkAwesome")
set(QT_FORK_AWESOME_ICON_ENGINE_LICENSE "GPL-2.0+")

# define general config
set(QT_FORK_AWESOME_ICON_ENGINE_IS_HEADER_ONLY NO)
set(QT_FORK_AWESOME_ICON_ENGINE_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(QT_FORK_AWESOME_ICON_ENGINE_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(QT_FORK_AWESOME_ICON_ENGINE_DATA_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine/cmake/modules")
set(QT_FORK_AWESOME_ICON_ENGINE_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine/cmake")
set(QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_QT_MODULES "Gui;Core")
set(QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_KF_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_QT_MODULES "Core;Gui")
set(QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_KF_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PACKAGES "c++utilities;qtforkawesome")
set(QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_HAS_QT_TRANSLATION_FILES NO)
set(QT_FORK_AWESOME_ICON_ENGINE_QT_RESOURCES )

# define mapping from CMake targets to pkg-config module names
set(PKG_CONFIG_qtforkawesomeiconengine "qtforkawesomeiconengine")

# define additional find_package arguments for required CMake-packages

# define library config, add imported target
set(QT_FORK_AWESOME_ICON_ENGINE_PACKAGE "qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB "qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB_IS_SHARED "ON")
set(QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE "OFF")
if(NOT TARGET "${QT_FORK_AWESOME_ICON_ENGINE_LIB}")
    # make dependencies of the library available
    # caveat: This currently does *not* cover Qt and KF modules which are so far only handled
    #         separately when using the function use_QT_FORK_AWESOME_ICON_ENGINE.

    # prefer static libraries if qtforkawesomeiconengine was configured this way during its build
    if (QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE)
        set(QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES ${CMAKE_FIND_LIBRARY_SUFFIXES})
        if (WIN32)
            set(CMAKE_FIND_LIBRARY_SUFFIXES .a .lib)
        else ()
            set(CMAKE_FIND_LIBRARY_SUFFIXES .a)
        endif ()
        set(QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS ${PKG_CONFIG_USE_STATIC_LIBS})
        set(PKG_CONFIG_USE_STATIC_LIBS ON)
    endif ()

    # find all required packages
    foreach (_REQUIRED_PACKAGE ${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PACKAGES})
        string(REGEX MATCH _REQUIRED_PACKAGE_MATCH "(.*)-([^-]*)" "${_REQUIRED_PACKAGE}")
        if (_REQUIRED_PACKAGE_MATCH)
            set(_REQUIRED_PACKAGE "${CMAKE_MATCH_1}")
            set(_REQUIRED_VERSION "${CMAKE_MATCH_2}")
        else ()
            unset(_REQUIRED_VERSION)
        endif ()
        string(REPLACE "::" "_" _REQUIRED_PACKAGE_VARNAME "${_REQUIRED_PACKAGE}")
        if (QT_FORK_AWESOME_ICON_ENGINE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME})
            set(_FIND_PACKAGE_ARGS ${QT_FORK_AWESOME_ICON_ENGINE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME}})
        else ()
            set(_FIND_PACKAGE_ARGS REQUIRED)
        endif ()
        if (_REQUIRED_VERSION)
            find_package("${_REQUIRED_PACKAGE}" "${_REQUIRED_VERSION}" ${_FIND_PACKAGE_ARGS})
        else ()
            find_package("${_REQUIRED_PACKAGE}" ${_FIND_PACKAGE_ARGS})
        endif()
    endforeach()

    # find all required pkg-config modules
    if (QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES)
        include(3rdParty)
        foreach (QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE ${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES})
            string(REPLACE "::" "_" QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE_VARNAME "${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE}")
            use_pkg_config_module(
                TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE}"
                PKG_CONFIG_MODULES "${PKG_CONFIG_${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE_VARNAME}}"
                LIBRARIES_VARIABLE DEV_NULL
                PKG_CONFIG_MODULES_VARIABLE DEV_NULL
            )
        endforeach ()
    endif ()

    # restore preference of static libraries
    if (QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE)
        set(CMAKE_FIND_LIBRARY_SUFFIXES ${QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES})
        unset(QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_CMAKE_FIND_LIBRARY_SUFFIXES)
        set(PKG_CONFIG_USE_STATIC_LIBS ${QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS})
        unset(QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_PKG_CONFIG_USE_STATIC_LIBS)
    endif ()

    # add target for the library itself
    include("${CMAKE_CURRENT_LIST_DIR}/qtforkawesomeiconengineTargets.cmake")
endif()

# define function to ease use of library in projects following conventions of c++utilities' build script
function(use_QT_FORK_AWESOME_ICON_ENGINE)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH "${QT_FORK_AWESOME_ICON_ENGINE_MODULE_DIRS}")
    set(CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}" PARENT_SCOPE)

    # parse arguments
    include(3rdParty)
    parse_arguments_for_use_functions(${ARGN})

    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${QT_FORK_AWESOME_ICON_ENGINE_LIB_DIR})
    if (ARGS_ONLY_HEADERS)
        set(TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_LIB}-headers")
    else ()
        set(TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_LIB}")
    endif ()
    set("${ARGS_LIBRARIES_VARIABLE}" "${${ARGS_LIBRARIES_VARIABLE}};${TARGET_NAME}" PARENT_SCOPE)
    set("${ARGS_PACKAGES_VARIABLE}" "${${ARGS_PACKAGES_VARIABLE}};${QT_FORK_AWESOME_ICON_ENGINE_PACKAGE}" PARENT_SCOPE)

    if (ARGS_ONLY_HEADERS)
        return ()
    endif ()

    # add required Qt and KF modules
    set(IMPORTED_QT_MODULES
        ${IMPORTED_QT_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_QT_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_QT_MODULES}
        PARENT_SCOPE
    )
    set(IMPORTED_KF_MODULES
        ${IMPORTED_KF_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_KF_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_KF_MODULES}
        PARENT_SCOPE
    )

    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(QT_FORK_AWESOME_ICON_ENGINE_HAS_QT_TRANSLATION_FILES)
        set(APP_SPECIFIC_QT_TRANSLATION_FILES "${APP_SPECIFIC_QT_TRANSLATION_FILES};qtforkawesomeiconengine" PARENT_SCOPE)
    endif()

    # add Qt resources if it is a static library
    if (NOT QT_FORK_AWESOME_ICON_ENGINE_LIB_IS_SHARED)
        set(STATIC_LIBRARIES_QT_RESOURCES "${STATIC_LIBRARIES_QT_RESOURCES};${QT_FORK_AWESOME_ICON_ENGINE_QT_RESOURCES}" PARENT_SCOPE)
    endif()
endfunction()

==> qtforkawesome-0.3.0-1-x86_64.pkg.tar.zst: usr/share/qtforkawesomeiconengine/cmake/qtforkawesomeiconengineConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# provide meta-data
set(qtforkawesomeiconengine_varname "QT_FORK_AWESOME_ICON_ENGINE")
set(qtforkawesomeiconengine_varname "QT_FORK_AWESOME_ICON_ENGINE")
set(QT_FORK_AWESOME_ICON_ENGINE_DISPLAY_NAME "QIconEngine for ForkAwesome")
set(QT_FORK_AWESOME_ICON_ENGINE_AUTHOR "Martchus")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION "0.3.0")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_MAJOR "0")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_MINOR "3")
set(QT_FORK_AWESOME_ICON_ENGINE_VERSION_PATCH "0")
set(QT_FORK_AWESOME_ICON_ENGINE_GIT_REV_COUNT "")
set(QT_FORK_AWESOME_ICON_ENGINE_GIT_LAST_COMMIT_ID "")
set(QT_FORK_AWESOME_ICON_ENGINE_URL "https://github.com/Martchus/qtforkawesome")
set(QT_FORK_AWESOME_ICON_ENGINE_DESCRIPTION "QIconEngine for ForkAwesome")
set(QT_FORK_AWESOME_ICON_ENGINE_LICENSE "GPL-2.0+")

# define general config
set(QT_FORK_AWESOME_ICON_ENGINE_IS_HEADER_ONLY NO)
set(QT_FORK_AWESOME_ICON_ENGINE_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include")
set(QT_FORK_AWESOME_ICON_ENGINE_BIN_DIR "${PACKAGE_PREFIX_DIR}/bin")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(QT_FORK_AWESOME_ICON_ENGINE_DATA_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_MODULE_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine/cmake/modules")
set(QT_FORK_AWESOME_ICON_ENGINE_CONFIG_DIRS "${PACKAGE_PREFIX_DIR}/share/qtforkawesomeiconengine/cmake")
set(QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_QT_MODULES "Gui;Core")
set(QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_KF_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_QT_MODULES "Core;Gui")
set(QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_KF_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PACKAGES "c++utilities;qtforkawesome")
set(QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES "")
set(QT_FORK_AWESOME_ICON_ENGINE_HAS_QT_TRANSLATION_FILES NO)
set(QT_FORK_AWESOME_ICON_ENGINE_QT_RESOURCES )

# define mapping from CMake targets to pkg-config module names
set(PKG_CONFIG_qtforkawesomeiconengine "qtforkawesomeiconengine")

# save policies before modifying them e.g. though the inclusion of 3rdParty
cmake_policy(PUSH)

# define additional find_package arguments for required CMake-packages

# define library config, add imported target
set(QT_FORK_AWESOME_ICON_ENGINE_PACKAGE "qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB "qtforkawesomeiconengine")
set(QT_FORK_AWESOME_ICON_ENGINE_LIB_IS_SHARED "ON")
set(QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE "OFF")
if(NOT TARGET "${QT_FORK_AWESOME_ICON_ENGINE_LIB}")
    # make dependencies of the library available
    # caveat: This currently does *not* cover Qt and KF modules which are so far only handled
    #         separately when using the function use_QT_FORK_AWESOME_ICON_ENGINE.

    # find c++utilities to use its CMake modules
    if (NOT QT_FORK_AWESOME_ICON_ENGINE_PACKAGE STREQUAL "c++utilities")
        find_package("c++utilities" ${QT_FORK_AWESOME_ICON_ENGINE_FIND_PACKAGE_ARGS_c++utilities} REQUIRED)
    endif ()

    # prefer static libraries if qtforkawesomeiconengine was configured this way during its build
    set(QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}")
    list(APPEND CMAKE_MODULE_PATH "${QT_FORK_AWESOME_ICON_ENGINE_MODULE_DIRS}")
    list(APPEND CMAKE_MODULE_PATH "${CPP_UTILITIES_MODULE_DIRS}")
    include(3rdPartyFunctions)
    if (QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE)
        save_library_preference()
        prefer_static_libraries()
    endif ()

    # find all required packages
    foreach (_REQUIRED_PACKAGE ${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PACKAGES})
        string(REGEX MATCH _REQUIRED_PACKAGE_MATCH "(.*)-([^-]*)" "${_REQUIRED_PACKAGE}")
        if (_REQUIRED_PACKAGE_MATCH)
            set(_REQUIRED_PACKAGE "${CMAKE_MATCH_1}")
            set(_REQUIRED_VERSION "${CMAKE_MATCH_2}")
        else ()
            unset(_REQUIRED_VERSION)
        endif ()
        string(REPLACE "::" "_" _REQUIRED_PACKAGE_VARNAME "${_REQUIRED_PACKAGE}")
        if (QT_FORK_AWESOME_ICON_ENGINE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME})
            set(_FIND_PACKAGE_ARGS ${QT_FORK_AWESOME_ICON_ENGINE_FIND_PACKAGE_ARGS_${_REQUIRED_PACKAGE_VARNAME}})
        else ()
            set(_FIND_PACKAGE_ARGS REQUIRED)
        endif ()
        if (_REQUIRED_VERSION)
            find_package("${_REQUIRED_PACKAGE}" "${_REQUIRED_VERSION}" ${_FIND_PACKAGE_ARGS})
        else ()
            find_package("${_REQUIRED_PACKAGE}" ${_FIND_PACKAGE_ARGS})
        endif()
    endforeach()

    # find all required pkg-config modules
    if (QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES)
        foreach (QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE ${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULES})
            string(REPLACE "::" "_" QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE_VARNAME "${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE}")
            use_pkg_config_module(
                TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE}"
                PKG_CONFIG_MODULES "${PKG_CONFIG_${QT_FORK_AWESOME_ICON_ENGINE_REQUIRED_PKG_CONFIG_MODULE_VARNAME}}"
                LIBRARIES_VARIABLE DEV_NULL
                PKG_CONFIG_MODULES_VARIABLE DEV_NULL
            )
        endforeach ()
    endif ()

    # restore preference of static libraries
    if (QT_FORK_AWESOME_ICON_ENGINE_STATIC_LINKAGE)
        restore_library_preference()
    endif ()

    # add target for the library itself
    include("${CMAKE_CURRENT_LIST_DIR}/qtforkawesomeiconengineTargets.cmake")

    # restore module path
    set(CMAKE_MODULE_PATH "${QT_FORK_AWESOME_ICON_ENGINE_DEFAULT_CMAKE_MODULE_PATH}")
endif()

# define function to ease use of library in projects following conventions of c++utilities' build script
function(use_QT_FORK_AWESOME_ICON_ENGINE)
    # make CMake modules of the project available
    list(APPEND CMAKE_MODULE_PATH "${QT_FORK_AWESOME_ICON_ENGINE_MODULE_DIRS}")
    set(CMAKE_MODULE_PATH "${CMAKE_MODULE_PATH}" PARENT_SCOPE)

    # parse arguments
    list(APPEND CMAKE_MODULE_PATH "${CPP_UTILITIES_MODULE_DIRS}")
    include(3rdParty)
    parse_arguments_for_use_functions(${ARGN})

    # link against library (also "link" against header-only libs to get compile defs and interface link libs)
    link_directories(${QT_FORK_AWESOME_ICON_ENGINE_LIB_DIR})
    if (ARGS_ONLY_HEADERS)
        set(TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_LIB}-headers")
    else ()
        set(TARGET_NAME "${QT_FORK_AWESOME_ICON_ENGINE_LIB}")
    endif ()
    set("${ARGS_LIBRARIES_VARIABLE}" "${${ARGS_LIBRARIES_VARIABLE}};${TARGET_NAME}" PARENT_SCOPE)
    set("${ARGS_PACKAGES_VARIABLE}" "${${ARGS_PACKAGES_VARIABLE}};${QT_FORK_AWESOME_ICON_ENGINE_PACKAGE}" PARENT_SCOPE)

    if (ARGS_ONLY_HEADERS)
        return ()
    endif ()

    # add required Qt and KF modules
    set(IMPORTED_QT_MODULES
        ${IMPORTED_QT_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_QT_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_QT_MODULES}
        PARENT_SCOPE
    )
    set(IMPORTED_KF_MODULES
        ${IMPORTED_KF_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PUBLIC_KF_MODULES}
        ${QT_FORK_AWESOME_ICON_ENGINE_PRIVATE_KF_MODULES}
        PARENT_SCOPE
    )

    # add required translations to APP_SPECIFIC_QT_TRANSLATION_FILES_ARRAY
    if(QT_FORK_AWESOME_ICON_ENGINE_HAS_QT_TRANSLATION_FILES)
        set(APP_SPECIFIC_QT_TRANSLATION_FILES "${APP_SPECIFIC_QT_TRANSLATION_FILES};qtforkawesomeiconengine" PARENT_SCOPE)
    endif()

    # add Qt resources if it is a static library
    if (NOT QT_FORK_AWESOME_ICON_ENGINE_LIB_IS_SHARED)
        set(STATIC_LIBRARIES_QT_RESOURCES "${STATIC_LIBRARIES_QT_RESOURCES};${QT_FORK_AWESOME_ICON_ENGINE_QT_RESOURCES}" PARENT_SCOPE)
    endif()
endfunction()

# restore policies
cmake_policy(POP)
